==> kubernetes-client_2.13-0.7.0-sources.jar: CronJob.scala <==
package io.k8s.api.batch.v1beta1

/* CronJob represents the configuration of a single cron job. */
import io.circe._
import io.circe.generic.semiauto._

case class CronJob(
  /* APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
  apiVersion: Option[String] = None,
  /* Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
  kind: Option[String] = None,
  /* Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata */
  metadata: Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None,
  /* Specification of the desired behavior of a cron job, including the schedule. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status */
  spec: Option[io.k8s.api.batch.v1beta1.CronJobSpec] = None,
  /* Current status of a cron job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status */
  status: Option[io.k8s.api.batch.v1beta1.CronJobStatus] = None
)

object CronJob {
  implicit lazy val encoder: Encoder.AsObject[CronJob] = deriveEncoder
  implicit lazy val decoder: Decoder[CronJob] = deriveDecoder
}

==> kubernetes-client_3-0.8.1-sources.jar: CronJob.scala <==
package io.k8s.api.batch.v1

/* CronJob represents the configuration of a single cron job. */
import io.circe._
import io.circe.generic.semiauto._

case class CronJob(
  /* APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
  apiVersion: Option[String] = None,
  /* Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
  kind: Option[String] = None,
  /* Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata */
  metadata: Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None,
  /* Specification of the desired behavior of a cron job, including the schedule. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status */
  spec: Option[io.k8s.api.batch.v1.CronJobSpec] = None,
  /* Current status of a cron job. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status */
  status: Option[io.k8s.api.batch.v1.CronJobStatus] = None
)

object CronJob {
  implicit lazy val encoder: Encoder.AsObject[CronJob] = deriveEncoder
  implicit lazy val decoder: Decoder[CronJob] = deriveDecoder
}
